@@ -104,6 +104,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 #endif
 	BOX_G(tr("Allow multiple instances"), settings->allow_multiple_instances > 0, multipleInstancesToggled(bool));
 	BOX_G(tr("Clear history on exit"), settings->clear_history_on_exit, clearHistoryToggled(bool));
+	BOX_G(tr("Close application with Escape key"), settings->close_with_esc, closeWithEscToggled(bool));
 	BOX_G(tr("Use keyboard keys for RPN"), settings->rpn_keys, rpnKeysToggled(bool));
 	BOX_G(tr("Use caret for bitwise XOR"), settings->caret_as_xor, caretAsXorToggled(bool));
 	BOX_G(tr("Keep above other windows"), settings->always_on_top, keepAboveToggled(bool));
@@ -117,6 +118,14 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->setCurrentIndex(combo->findData(settings->title_type));
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(titleChanged(int)));
 	l2->addWidget(combo, r, 1); r++;
+	l2->addWidget(new QLabel(tr("Tooltips:"), this), r, 0);
+	combo = new QComboBox(this);
+	combo->addItem(tr("Show all"), 1);
+	combo->addItem(tr("Hide in keypad"), 2);
+	combo->addItem(tr("Hide all"), 0);
+	combo->setCurrentIndex(combo->findData(settings->enable_tooltips));
+	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(tooltipsChanged(int)));
+	l2->addWidget(combo, r, 1); r++;
 	l2->addWidget(new QLabel(tr("Style:"), this), r, 0);
 	combo = new QComboBox(this);
 	QStringList list = QStyleFactory::keys();
@@ -192,7 +201,9 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	l2->addWidget(combo, r, 1); r++;
 	BOX_G(tr("Simplified percentage calculation"), settings->simplified_percentage, simplifiedPercentageToggled(bool));
 	BOX_G(tr("Read precision"), settings->evalops.parse_options.read_precision != DONT_READ_PRECISION, readPrecisionToggled(bool));
+	BOX_G(tr("Allow concise uncertainty input"), CALCULATOR->conciseUncertaintyInputEnabled(), conciseUncertaintyInputToggled(bool));
 	BOX_G(tr("Limit implicit multiplication"), settings->evalops.parse_options.limit_implicit_multiplication, limitImplicitToggled(bool));
+	BOX_G(tr("Interpret unrecognized symbols as variables"), settings->evalops.parse_options.unknowns_enabled, unknownsToggled(bool));
 	l2->addWidget(new QLabel(tr("Interval calculation:"), this), r, 0);
 	combo = new QComboBox(this);
 	combo->addItem(tr("Variance formula"), INTERVAL_CALCULATION_VARIANCE_FORMULA);
@@ -236,6 +247,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->addItem(tr("Significant digits"), INTERVAL_DISPLAY_SIGNIFICANT_DIGITS);
 	combo->addItem(tr("Interval"), INTERVAL_DISPLAY_INTERVAL);
 	combo->addItem(tr("Plus/minus"), INTERVAL_DISPLAY_PLUSMINUS);
+	combo->addItem(tr("Relative"), INTERVAL_DISPLAY_RELATIVE);
+	combo->addItem(tr("Concise"), INTERVAL_DISPLAY_CONCISE);
 	combo->addItem(tr("Midpoint"), INTERVAL_DISPLAY_MIDPOINT);
 	combo->addItem(tr("Lower"), INTERVAL_DISPLAY_LOWER);
 	combo->addItem(tr("Upper"), INTERVAL_DISPLAY_UPPER);
@@ -264,6 +277,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	l->addStretch(1);
 	l2 = new QGridLayout(w3); l2->setSizeConstraint(QLayout::SetFixedSize);
 	r = 0;
+	BOX_G(tr("Enable units"), settings->evalops.parse_options.units_enabled, unitsToggled(bool));
 	BOX_G(tr("Abbreviate names"), settings->printops.abbreviate_names, abbreviateNamesToggled(bool));
 	BOX_G(tr("Use binary prefixes for information units"), CALCULATOR->usesBinaryPrefixes() > 0, binaryPrefixesToggled(bool));
 	l2->addWidget(new QLabel(tr("Automatic unit conversion:"), this), r, 0);
@@ -367,6 +381,10 @@ void PreferencesDialog::keepAboveToggled(bool b) {
 	show();
 	emit alwaysOnTopChanged();
 }
+void PreferencesDialog::tooltipsChanged(int i) {
+	settings->enable_tooltips = qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
+	emit enableTooltipsChanged();
+}
 void PreferencesDialog::expressionStatusToggled(bool b) {
 	settings->display_expression_status = b;
 	statusDelayWidget->setEnabled(b);
@@ -466,7 +484,7 @@ void PreferencesDialog::formatToggled(bool b) {
 }
 void PreferencesDialog::parsingModeChanged(int i) {
 	settings->evalops.parse_options.parsing_mode = (ParsingMode) qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
-	settings->implicit_question_asked = (settings->evalops.parse_options.parsing_mode == PARSING_MODE_CONVENTIONAL || settings->evalops.parse_options.parsing_mode == PARSING_MODE_IMPLICIT_MULTIPLICATION_FIRST);
+	if(settings->evalops.parse_options.parsing_mode == PARSING_MODE_CONVENTIONAL || settings->evalops.parse_options.parsing_mode == PARSING_MODE_IMPLICIT_MULTIPLICATION_FIRST) settings->implicit_question_asked = true;
 	emit expressionFormatUpdated(false);
 }
 void PreferencesDialog::temperatureCalculationChanged(int i) {
@@ -489,6 +507,10 @@ void PreferencesDialog::exratesChanged(int i) {
 		exratesSpin->setPrefix(str.right(index));
 	}
 }
+void PreferencesDialog::unitsToggled(bool b) {
+	settings->evalops.parse_options.units_enabled = b;
+	emit expressionFormatUpdated(false);
+}
 void PreferencesDialog::binaryPrefixesToggled(bool b) {
 	CALCULATOR->useBinaryPrefixes(b ? 1 : 0);
 	emit resultFormatUpdated();
@@ -537,6 +559,9 @@ void PreferencesDialog::copyAsciiWithoutUnitsToggled(bool b) {
 void PreferencesDialog::caretAsXorToggled(bool b) {
 	settings->caret_as_xor = b;
 }
+void PreferencesDialog::closeWithEscToggled(bool b) {
+	settings->close_with_esc = b;
+}
 void PreferencesDialog::mixedUnitsToggled(bool b) {
 	if(b) settings->evalops.mixed_units_conversion = MIXED_UNITS_CONVERSION_DEFAULT;
 	else settings->evalops.mixed_units_conversion = MIXED_UNITS_CONVERSION_NONE;
@@ -579,11 +604,19 @@ void PreferencesDialog::intervalDisplayChanged(int i) {
 	}
 	emit resultFormatUpdated();
 }
+void PreferencesDialog::conciseUncertaintyInputToggled(bool b) {
+	CALCULATOR->setConciseUncertaintyInputEnabled(b);
+	emit expressionFormatUpdated(false);
+}
 void PreferencesDialog::limitImplicitToggled(bool b) {
 	settings->evalops.parse_options.limit_implicit_multiplication = b;
 	settings->printops.limit_implicit_multiplication = b;
 	emit expressionFormatUpdated(true);
 }
+void PreferencesDialog::unknownsToggled(bool b) {
+	settings->evalops.parse_options.unknowns_enabled = b;
+	emit expressionFormatUpdated(false);
+}
 void PreferencesDialog::titleChanged(int i) {
 	settings->title_type = qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
 	emit titleTypeChanged();
