@@ -302,7 +302,7 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 			printops.interval_display = INTERVAL_DISPLAY_SIGNIFICANT_DIGITS; adaptive_interval_display = true;
 		} else {
 			v--;
-			if(v >= INTERVAL_DISPLAY_SIGNIFICANT_DIGITS && v <= INTERVAL_DISPLAY_UPPER) {
+			if(v >= INTERVAL_DISPLAY_SIGNIFICANT_DIGITS && v <= INTERVAL_DISPLAY_RELATIVE) {
 				printops.interval_display = (IntervalDisplay) v; adaptive_interval_display = false;
 			}
 		}
@@ -454,6 +454,8 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 		if(v >= INTERVAL_CALCULATION_NONE && v <= INTERVAL_CALCULATION_SIMPLE_INTERVAL_ARITHMETIC) {
 			evalops.interval_calculation = (IntervalCalculation) v;
 		}
+	} else if(svar == "concise_uncertainty_input") {
+		CALCULATOR->setConciseUncertaintyInputEnabled(v);
 	} else if(svar == "chain_mode") {
 		chain_mode = v;
 	} else if(svar == "rpn_mode") {
@@ -563,6 +565,10 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 			ignore_locale = v;
 		} else if(svar == "window_title_mode") {
 			if(v >= 0 && v <= 4) title_type = v;
+		} else if(svar == "enable_tooltips") {
+			enable_tooltips = v;
+			if(enable_tooltips < 0) enable_tooltips = 1;
+			else if(enable_tooltips > 2) enable_tooltips = 2;
 		} else if(svar == "auto_update_exchange_rates") {
 			auto_update_exchange_rates = v;
 		} else if(svar == "display_expression_status") {
@@ -680,6 +686,8 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 			printops.spell_out_logical_operators = v;
 		} else if(svar == "caret_as_xor") {
 			caret_as_xor = v;
+		} else if(svar == "close_with_esc") {
+			close_with_esc = v;
 		} else if(svar == "copy_ascii") {
 			copy_ascii = v;
 		} else if(svar == "copy_ascii_without_units") {
@@ -728,6 +736,7 @@ void QalculateQtSettings::loadPreferences() {
 	CALCULATOR->useIntervalArithmetic(true);
 	CALCULATOR->setTemperatureCalculationMode(TEMPERATURE_CALCULATION_HYBRID);
 	CALCULATOR->useBinaryPrefixes(0);
+	CALCULATOR->setConciseUncertaintyInputEnabled(false);
 
 	current_workspace = "";
 	save_workspace = -1;
@@ -811,6 +820,7 @@ void QalculateQtSettings::loadPreferences() {
 	dual_fraction = -1;
 	dual_approximation = -1;
 	auto_update_exchange_rates = 7;
+	close_with_esc = false;
 	rpn_mode = false;
 	rpn_keys = true;
 	rpn_shown = false;
@@ -822,6 +832,7 @@ void QalculateQtSettings::loadPreferences() {
 	color = 1;
 	colorize_result = true;
 	format_result = true;
+	enable_tooltips = 1;
 	chain_mode = false;
 	enable_input_method = false;
 	enable_completion = true;
@@ -915,7 +926,7 @@ void QalculateQtSettings::loadPreferences() {
 	max_plot_time = 5;
 
 	preferences_version[0] = 4;
-	preferences_version[1] = 7;
+	preferences_version[1] = 8;
 	preferences_version[2] = 0;
 
 	if(file) {
@@ -1233,6 +1244,7 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 		fprintf(file, "save_definitions_on_exit=%i\n", save_defs_on_exit);
 		fprintf(file, "clear_history_on_exit=%i\n", clear_history_on_exit);
 		fprintf(file, "enable_input_method=%i\n", enable_input_method);
+		fprintf(file, "enable_tooltips=%i\n", enable_tooltips);
 		fprintf(file, "display_expression_status=%i\n", display_expression_status);
 		fprintf(file, "expression_status_delay=%i\n", expression_status_delay);
 		fprintf(file, "enable_completion=%i\n", enable_completion);
@@ -1320,6 +1332,7 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 		if(default_signed >= 0) fprintf(file, "signed_integer=%i\n", default_signed);
 		fprintf(file, "spell_out_logical_operators=%i\n", printops.spell_out_logical_operators);
 		fprintf(file, "caret_as_xor=%i\n", caret_as_xor);
+		fprintf(file, "close_with_esc=%i\n", close_with_esc);
 		fprintf(file, "copy_ascii=%i\n", copy_ascii);
 		fprintf(file, "copy_ascii_without_units=%i\n", copy_ascii_without_units);
 		fprintf(file, "digit_grouping=%i\n", printops.digit_grouping);
@@ -1397,6 +1410,7 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 		if(dual_approximation < 0) fprintf(file, "approximation=%i\n", -1);
 		else if(dual_approximation > 0) fprintf(file, "approximation=%i\n", APPROXIMATION_APPROXIMATE + 1);
 		else fprintf(file, "approximation=%i\n", evalops.approximation);
+		fprintf(file, "concise_uncertainty_input=%i\n", CALCULATOR->conciseUncertaintyInputEnabled());
 		fprintf(file, "interval_calculation=%i\n", evalops.interval_calculation);
 		fprintf(file, "rpn_mode=%i\n", rpn_mode);
 		fprintf(file, "chain_mode=%i\n", chain_mode);
